Package: NewmanOmics
Type: Package
LazyData: true
Title: Extending the Newman Studentized Range Statistic to
        Transcriptomics
Version: 1.1.3
Date: 2026-06-06
Authors@R: c(person(given = "Zachary B.", family = "Abrams", role = "aut"),
               person(given = "Greg", family = "Gershkowitz", role = "aut"),
               person(given = "Anoushka", family = "Joglekar", role = "aut"),
               person(given = "Chao", family = "Liu", role = "aut"),
               person(given = c("Kevin", "R."), family = "Coombes",
                      role = c("aut", "cre"), email = "krc@silicovore.com"))
Description: Extends the classical Newman studentized range statistic
  in various ways that can be applied to genome-scale transcriptomic
  or other expression data.
License: Apache License (== 2.0)
Depends: R (>= 4.4)
Imports: methods, stats, graphics, grDevices, oompaBase
VignetteBuilder: knitr
Suggests: knitr, rmarkdown
URL: http://oompa.r-forge.r-project.org/
NeedsCompilation: no
Packaged: 2026-07-06 13:44:07 UTC; kevin
Author: Zachary B. Abrams [aut],
  Greg Gershkowitz [aut],
  Anoushka Joglekar [aut],
  Chao Liu [aut],
  Kevin R. Coombes [aut, cre]
Maintainer: Kevin R. Coombes <krc@silicovore.com>
Repository: CRAN
Date/Publication: 2026-07-06 14:20:19 UTC
Built: R 4.6.1; ; 2026-07-06 14:32:57 UTC; unix
