import("methods")

importFrom("stats", "approxfun", "density", "integrate", "loess",
           "pnorm", "predict", "rnorm", "sd",
           "dbeta", "nlm", "optimize")
importFrom("graphics", "plot", "hist", "points", "legend",
           "lines", "mtext", "par")
importFrom("grDevices", "dev.interactive", "devAskNewPage")

importFrom("oompaBase", "matrixMean", "matrixVar")

export("bankStat", "createBank")
export("pairedStat")

exportMethods("plot", "hist", "[", "dim")

exportClass("MixOf3Beta")
export("fitMix3", "computeFDR", "computeCutoff")
exportMethods("image")
